import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import Swal from 'sweetalert2';
import axios from 'axios';
import * as CryptoJS from 'crypto-js';
import * as shajs from 'sha.js';

@Component({
  selector: 'ppa-user-data-change',
  templateUrl: './password-change.component.html',
  styleUrls: ['./password-change.component.scss']
})
   
export class PasswordChangeComponent implements OnInit {

  @Output() successModify = new EventEmitter();
  @Input() userData;

  public name = ''
  public lname = ''
  public position = ''
  public gender = ''
  public phone = ''
  public email = ''
  public area = ''
  public sector = ''
  public currentPassword = ''
  public newPassword = ''
  public newConfirmPassword = ''
  public encryptSecretKey="alexis"

  constructor() { }



encryptData(data) {

  try {
    return CryptoJS.AES.encrypt(JSON.stringify(data), this.encryptSecretKey).toString();
  } catch (e) {
   // console.log(e);
  }
}

  sendModify(){
    const self = this;
    if(this.statusPassword == 'No procede'){
      Swal.fire({
        title: 'Error',
        text: 'Su contraseña no coincide con los criterios requeridos. Verifique e intente nuevamente',
        type: 'error'
      })
    }else if(this.newConfirmPassword == this.newPassword){

      let sentToken = localStorage.getItem("auth-ppa-agrosuper")

      axios({
        method: 'post',
        url: 'https://api-dev.tecnoandina.cl/OAuth/update-data',
        data: {
          nombre: self.name,
          apellido:self.lname,
          cargo:self.position,
          sexo:self.gender, 
          usuario:self.email, 
          telefono:self.phone, 
          zona:self.area,
          sector:self.sector,
          newPassword:shajs('sha256').update(self.newPassword).digest('hex'),
          oldPassword:shajs('sha256').update(self.currentPassword).digest('hex'),
        },
        headers:{
          "Authorization":'Bearer '+sentToken
        },
        timeout:30000,
      }).then(function(response){
        Swal.fire({
          title: 'Solicitud exitosa',
          text: 'Sus datos se han modificado correctamente',
          type: 'success'
        });
        self.successModify.emit({
          nombre: self.name,
          apellido:self.lname,
          cargo:self.position,
          sexo:self.gender, 
          usuario:self.email, 
          telefono:self.phone, 
          zona:self.area,
          sector:self.sector
        })
      }).catch(function(error){
        Swal.fire({
          title:'ERROR',
          text:'Ocurrió un error al intentar registrar sus datos. Intente nuevamente.',
          type:'error'
        })
      })

    }else{
      Swal.fire({
        title: 'ERROR',
        text: 'Las contraseñas no coinciden',
        type: 'error'
      })
    }
  }

  public statusPassword = 'No procede'
  public status = {
    capitalFlag: false,
    numberFlag: false,
    numberPas: false,
  }

  colorCheck(prop){
    if(prop == 'confirmPasswords'){
      if(this.newPassword == this.newConfirmPassword && this.newPassword != ''){
        return 'ppa-check-success pr-2'
      }else{
        return 'pr-2'
      }
    }else if(this.status[prop] == true){
      return 'ppa-check-success pr-2'
    }else{
      return 'pr-2'
    }
  }
  checkString(val) {
    let ch;
    let i;
    let message;
    
    this.status = {
      capitalFlag: false,
      numberFlag: false,
      numberPas: false,
    }

    for(i = 0; i < val.length ; i++) {
        ch = val.charAt(i);

        if( val.length >= 8) {
            this.status.numberFlag = true;
        }

        if('A' <= val[i] && val[i] <= 'Z'){
          this.status.capitalFlag = true;
        } // check if you have an uppercase
         
        if('0' <= val[i] && val[i] <= '9'){
          this.status.numberPas = true
        } 

        if(this.status.numberPas == true && this.status.numberFlag == true && this.status.capitalFlag == true){
          this.statusPassword = 'Procede'
          return 'Procede';
        }else if(i == (val.length - 1)){
          this.statusPassword = 'No procede'
          return 'No procede';
        }
    }
  }

  formatInput(v){
    if(v == true){
      return 'form-control ppa-input-border ppa-input-with-error'
    }else{
      return 'form-control ppa-input-border '
    }
  }
  setInputs(v,v2){
    if(v == 'fg1'){
      if(v2 == ''){
        return 'form-group pt-3'
      }else{
        return 'form-group pt-3 form-group-valid'
      }
    }else if(v == 'fg2'){
      if(v2 == ''){
        return 'form-group'
      }else{
        return 'form-group form-group-valid'
      }
    }else if(v == 1){
      if(v2 == ''){
        return 'form-control-placeholder'
      }else{
        return 'form-control-placeholder ppa-input-with-text'
      }
    }else{
      if(v2 == ''){
        return 'form-control-placeholder'
      }else{
        return 'form-control-placeholder ppa-input-with-text'
      }
    }

  }

  ngOnInit(): void {
    if(this.userData != undefined){
      this.name = this.userData.nombre
      this.lname = this.userData.apellido
      this.position = this.userData.cargo
      this.phone = this.userData.telefono
      this.email = this.userData.email
      this.area = this.userData.zona
      this.gender = this.userData.sexo
      this.sector = this.userData.sector
    }
  }

}
